<?php
/**
 * Plugin Name:     The Events Calendar Extension: Select Default Event Times
 * Description:     Adds two settings boxes to Wp Admin > Events > Settings > General for changing the default times for events.
 * Version:         1.0.0
 * Extension Class: Tribe__Extension__Default_Event_Times
 * Author:          Modern Tribe, Inc.
 * Author URI:      http://m.tri.be/1971
 * License:         GPLv2 or later
 * License URI:     https://www.gnu.org/licenses/gpl-2.0.html
 */

// Do not load unless Tribe Common is fully loaded. Also prevents direct loads.
if ( ! class_exists( 'Tribe__Extension' ) ) {
	return;
}

/**
 * Extension main class, class begins loading on init() function.
 */
class Tribe__Extension__Default_Event_Times extends Tribe__Extension {

	/**
	 * Setup the Extension's properties.
	 *
	 * This always executes even if the required plugins are not present.
	 */
	public function construct() {
		$this->add_required_plugin( 'Tribe__Events__Main', '4.4' );

		$this->set_url( 'https://theeventscalendar.com/extensions/set-default-event-times/' );
	}

	/**
	 * Extension initialization and hooks.
	 */
	public function init() {
		add_filter( 'tribe_events_meta_box_timepicker_default', array( $this, 'the_times_they_are_a_changin' ), 10, 4 );
		add_action( 'admin_init', array( $this, 'add_settings' ) );
	}

	/**
	 * Adds settings options
	 */
	public function add_settings() {
		require_once dirname( __FILE__ ) . '/src/Tribe/Extension/Settings_Helper.php';
		$setting_helper = new Tribe__Extension__Settings_Helper();

		$new_attendee_fields = array(
			'event_default_time_start' => array(
				'type' => 'text',
				'validation_type' => 'none',
				'label' => esc_html__( 'Default Start Time', 'tribe-extension' ),
				'default' => '08:00:00',
				'tooltip' => esc_html__( 'The default start time for events. Use the international 24 hour HH:MM:SS format.', 'tribe-extension' ),
			),
			'event_default_time_end' => array(
				'type' => 'text',
				'validation_type' => 'none',
				'label' => esc_html__( 'Default End Time', 'tribe-extension' ),
				'default' => '17:00:00',
				'tooltip' => esc_html__( 'The default end time for events. Use the international 24 hour HH:MM:SS format.', 'tribe-extension' ),
			),
		);

		$setting_helper->add_fields(
			$new_attendee_fields,
			'general',
			'multiDayCutoff',
			true
		);
	}

	/**
	 * Checks if the specified string is in the 24hr time format
	 *
	 * @param string $time The time string
	 *
	 * @return bool Returns true if passed a string in HH:MM:SS format
	 */
	protected function is_hms_time( $time ) {
		$time_format = '/^([01]\d|2[0-3]):([0-5]\d):([0-5]\d)$/';
		return (bool) preg_match( $time_format, $time );
	}

	/*
	 * Alter the default start/end times
	 *
	 * @see tribe_events_meta_box_timepicker_default
	 */
	public function the_times_they_are_a_changin( $default, $type, $date, $metabox ) {

		if ( ! $metabox->is_auto_draft() ) {
			return $default;
		}

		$new_default = false;

		if ( 'start' === $type  ) {
			$new_default = $start = tribe_get_option( 'event_default_time_start', false );
		} elseif ( 'end' === $type ) {
			$new_default = $start = tribe_get_option( 'event_default_time_end', false );
		}

		if ( false !== $new_default && $this->is_hms_time( $new_default ) ) {
			$default = $new_default;
		}

		return $default;
	}
}